aboutsummaryrefslogtreecommitdiff
path: root/src/constants.ts
diff options
context:
space:
mode:
Diffstat (limited to 'src/constants.ts')
-rw-r--r--src/constants.ts19
1 files changed, 11 insertions, 8 deletions
diff --git a/src/constants.ts b/src/constants.ts
index 27f413b..ddc9bc3 100644
--- a/src/constants.ts
+++ b/src/constants.ts
@@ -223,24 +223,27 @@ export async function addSlayers(addingSlayers: string[]): Promise<void> {
await constants.addJSONConstants('slayers.json', addingSlayers, 'slayer')
}
-/** Fetch all the known SkyBlock slayer names as an array of strings */
+/** Fetch all the known SkyBlock minion names as an array of strings */
export async function fetchMinions(): Promise<string[]> {
return await constants.fetchJSONConstant('minions.json')
}
-export async function fetchSkillXp(): Promise<number[]> {
- return await constants.fetchJSONConstant('manual/skill_xp.json')
+/** Add minions to skyblock-constants. This has caching so it's fine to call many times */
+export async function addMinions(addingMinions: string[]): Promise<void> {
+ await constants.addJSONConstants('minions.json', addingMinions, 'minion')
}
-export async function fetchSkillXpEasier(): Promise<number[]> {
- return await constants.fetchJSONConstant('manual/skill_xp_easier.json')
+/** Fetch all the known SkyBlock pet ids as an array of strings */
+export async function fetchPets(): Promise<string[]> {
+ return await constants.fetchJSONConstant('pets.json')
}
-/** Add skills to skyblock-constants. This has caching so it's fine to call many times */
-export async function addMinions(addingMinions: string[]): Promise<void> {
- await constants.addJSONConstants('minions.json', addingMinions, 'minion')
+/** Add pet ids to skyblock-constants. This has caching so it's fine to call many times */
+export async function addPets(addingPets: string[]): Promise<void> {
+ await constants.addJSONConstants('pets.json', addingPets, 'pet')
}
+
interface constantValues {
max_minions?: number
max_fairy_souls?: number